==> zio-aws-grafana_3-5.17.187.1-sources.jar: zio/aws/grafana/model/DataSourceType.scala <==
package zio.aws.grafana.model
import scala.jdk.CollectionConverters.*
sealed trait DataSourceType {
  def unwrap: software.amazon.awssdk.services.grafana.model.DataSourceType
}
object DataSourceType {
  def wrap(
      value: software.amazon.awssdk.services.grafana.model.DataSourceType
  ): zio.aws.grafana.model.DataSourceType = value match {
    case software.amazon.awssdk.services.grafana.model.DataSourceType.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.grafana.model.DataSourceType.AMAZON_OPENSEARCH_SERVICE =>
      val r = AMAZON_OPENSEARCH_SERVICE
      r
    case software.amazon.awssdk.services.grafana.model.DataSourceType.CLOUDWATCH =>
      val r = CLOUDWATCH
      r
    case software.amazon.awssdk.services.grafana.model.DataSourceType.PROMETHEUS =>
      val r = PROMETHEUS
      r
    case software.amazon.awssdk.services.grafana.model.DataSourceType.XRAY =>
      val r = XRAY
      r
    case software.amazon.awssdk.services.grafana.model.DataSourceType.TIMESTREAM =>
      val r = TIMESTREAM
      r
    case software.amazon.awssdk.services.grafana.model.DataSourceType.SITEWISE =>
      val r = SITEWISE
      r
    case software.amazon.awssdk.services.grafana.model.DataSourceType.ATHENA =>
      val r = ATHENA
      r
    case software.amazon.awssdk.services.grafana.model.DataSourceType.REDSHIFT =>
      val r = REDSHIFT
      r
  }
  case object unknownToSdkVersion extends zio.aws.grafana.model.DataSourceType {
    override def unwrap
        : software.amazon.awssdk.services.grafana.model.DataSourceType =
      software.amazon.awssdk.services.grafana.model.DataSourceType.UNKNOWN_TO_SDK_VERSION
  }
  case object AMAZON_OPENSEARCH_SERVICE
      extends zio.aws.grafana.model.DataSourceType {
    override def unwrap
        : software.amazon.awssdk.services.grafana.model.DataSourceType =
      software.amazon.awssdk.services.grafana.model.DataSourceType.AMAZON_OPENSEARCH_SERVICE
  }
  case object CLOUDWATCH extends zio.aws.grafana.model.DataSourceType {
    override def unwrap
        : software.amazon.awssdk.services.grafana.model.DataSourceType =
      software.amazon.awssdk.services.grafana.model.DataSourceType.CLOUDWATCH
  }
  case object PROMETHEUS extends zio.aws.grafana.model.DataSourceType {
    override def unwrap
        : software.amazon.awssdk.services.grafana.model.DataSourceType =
      software.amazon.awssdk.services.grafana.model.DataSourceType.PROMETHEUS
  }
  case object XRAY extends zio.aws.grafana.model.DataSourceType {
    override def unwrap
        : software.amazon.awssdk.services.grafana.model.DataSourceType =
      software.amazon.awssdk.services.grafana.model.DataSourceType.XRAY
  }
  case object TIMESTREAM extends zio.aws.grafana.model.DataSourceType {
    override def unwrap
        : software.amazon.awssdk.services.grafana.model.DataSourceType =
      software.amazon.awssdk.services.grafana.model.DataSourceType.TIMESTREAM
  }
  case object SITEWISE extends zio.aws.grafana.model.DataSourceType {
    override def unwrap
        : software.amazon.awssdk.services.grafana.model.DataSourceType =
      software.amazon.awssdk.services.grafana.model.DataSourceType.SITEWISE
  }
  case object ATHENA extends zio.aws.grafana.model.DataSourceType {
    override def unwrap
        : software.amazon.awssdk.services.grafana.model.DataSourceType =
      software.amazon.awssdk.services.grafana.model.DataSourceType.ATHENA
  }
  case object REDSHIFT extends zio.aws.grafana.model.DataSourceType {
    override def unwrap
        : software.amazon.awssdk.services.grafana.model.DataSourceType =
      software.amazon.awssdk.services.grafana.model.DataSourceType.REDSHIFT
  }
}

==> zio-aws-grafana_3-7.21.15.7-sources.jar: zio/aws/grafana/model/DataSourceType.scala <==
package zio.aws.grafana.model
import scala.jdk.CollectionConverters.*
sealed trait DataSourceType {
  def unwrap: software.amazon.awssdk.services.grafana.model.DataSourceType
}
object DataSourceType {
  def wrap(
      value: software.amazon.awssdk.services.grafana.model.DataSourceType
  ): zio.aws.grafana.model.DataSourceType = value match {
    case software.amazon.awssdk.services.grafana.model.DataSourceType.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.grafana.model.DataSourceType.AMAZON_OPENSEARCH_SERVICE =>
      val r = AMAZON_OPENSEARCH_SERVICE
      r
    case software.amazon.awssdk.services.grafana.model.DataSourceType.CLOUDWATCH =>
      val r = CLOUDWATCH
      r
    case software.amazon.awssdk.services.grafana.model.DataSourceType.PROMETHEUS =>
      val r = PROMETHEUS
      r
    case software.amazon.awssdk.services.grafana.model.DataSourceType.XRAY =>
      val r = XRAY
      r
    case software.amazon.awssdk.services.grafana.model.DataSourceType.TIMESTREAM =>
      val r = TIMESTREAM
      r
    case software.amazon.awssdk.services.grafana.model.DataSourceType.SITEWISE =>
      val r = SITEWISE
      r
    case software.amazon.awssdk.services.grafana.model.DataSourceType.ATHENA =>
      val r = ATHENA
      r
    case software.amazon.awssdk.services.grafana.model.DataSourceType.REDSHIFT =>
      val r = REDSHIFT
      r
    case software.amazon.awssdk.services.grafana.model.DataSourceType.TWINMAKER =>
      val r = TWINMAKER
      r
  }
  case object unknownToSdkVersion extends zio.aws.grafana.model.DataSourceType {
    override def unwrap
        : software.amazon.awssdk.services.grafana.model.DataSourceType =
      software.amazon.awssdk.services.grafana.model.DataSourceType.UNKNOWN_TO_SDK_VERSION
  }
  case object AMAZON_OPENSEARCH_SERVICE
      extends zio.aws.grafana.model.DataSourceType {
    override def unwrap
        : software.amazon.awssdk.services.grafana.model.DataSourceType =
      software.amazon.awssdk.services.grafana.model.DataSourceType.AMAZON_OPENSEARCH_SERVICE
  }
  case object CLOUDWATCH extends zio.aws.grafana.model.DataSourceType {
    override def unwrap
        : software.amazon.awssdk.services.grafana.model.DataSourceType =
      software.amazon.awssdk.services.grafana.model.DataSourceType.CLOUDWATCH
  }
  case object PROMETHEUS extends zio.aws.grafana.model.DataSourceType {
    override def unwrap
        : software.amazon.awssdk.services.grafana.model.DataSourceType =
      software.amazon.awssdk.services.grafana.model.DataSourceType.PROMETHEUS
  }
  case object XRAY extends zio.aws.grafana.model.DataSourceType {
    override def unwrap
        : software.amazon.awssdk.services.grafana.model.DataSourceType =
      software.amazon.awssdk.services.grafana.model.DataSourceType.XRAY
  }
  case object TIMESTREAM extends zio.aws.grafana.model.DataSourceType {
    override def unwrap
        : software.amazon.awssdk.services.grafana.model.DataSourceType =
      software.amazon.awssdk.services.grafana.model.DataSourceType.TIMESTREAM
  }
  case object SITEWISE extends zio.aws.grafana.model.DataSourceType {
    override def unwrap
        : software.amazon.awssdk.services.grafana.model.DataSourceType =
      software.amazon.awssdk.services.grafana.model.DataSourceType.SITEWISE
  }
  case object ATHENA extends zio.aws.grafana.model.DataSourceType {
    override def unwrap
        : software.amazon.awssdk.services.grafana.model.DataSourceType =
      software.amazon.awssdk.services.grafana.model.DataSourceType.ATHENA
  }
  case object REDSHIFT extends zio.aws.grafana.model.DataSourceType {
    override def unwrap
        : software.amazon.awssdk.services.grafana.model.DataSourceType =
      software.amazon.awssdk.services.grafana.model.DataSourceType.REDSHIFT
  }
  case object TWINMAKER extends zio.aws.grafana.model.DataSourceType {
    override def unwrap
        : software.amazon.awssdk.services.grafana.model.DataSourceType =
      software.amazon.awssdk.services.grafana.model.DataSourceType.TWINMAKER
  }
}
